Cy_sm calculates the normalized sparse kernel for a fixed
set of bump function hyperparameters and returns the nonzero entries. Note
that the matrix is calculated and returned in dense format.
crossCy_sm(
Xdists,
coords,
Pcoords,
d,
n1,
n2,
r0,
s0,
cstat_opt,
normalize,
bumpLocs,
rads,
ampls,
shps,
Xdist1_sq,
Xdist2_sq,
Xdist12,
Sigma11,
Sigma22,
Sigma12,
PSigma11,
PSigma22,
PSigma12,
nu,
log_sigma_vec,
Plog_sigma_vec
)Returns a sparse matrix (N x 3) of the nonzero elements of the product between the core and sparse kernel.
N x N matrix of Euclidean distances
N x d matrix of coordinate/input locations
N x d matrix of coordinate/input locations
Scalar; dimension of the spatial domain.
Scalar; number of outer products.
Scalar; number of bump functions in each outer product.
Scalar; length-scale of sparse stationary kernel.
Scalar; signal-variance of sparse stationary kernel.
Scalar; determines the compactly supported kernel. See Details.
Logical; should C_sparse have 1's along the diagonal (1 = TRUE)
Array of bump function locations (n2*d x n1)
Matrix of bump function radii (n1 x n2; denoted \(r_{ij}\))
Matrix of bump function amplitudes (n1 x n2; denoted \(a_{ij}\))
Matrix of bump function shape parameters (n1 x n2; denoted \(b_{ij}\))
N x N matrix; contains values of pairwise squared distances in the x-coordinate.
N x N matrix; contains values of pairwise squared distances in the y-coordinate.
N x N matrix; contains values of pairwise signed cross-
distances between the x- and y-coordinates. The sign of each element is
important; see nsDist function for the details of this calculation.
in the x-coordinate.
Vector of length N; contains the 1-1 element of the anisotropy process for each station.
Vector of length N; contains the 2-2 element of the anisotropy process for each station.
Vector of length N; contains the 1-2 element of the anisotropy process for each station.
Vector of length N; contains the 1-1 element of the anisotropy process for each station.
Vector of length N; contains the 2-2 element of the anisotropy process for each station.
Vector of length N; contains the 1-2 element of the anisotropy process for each station.
Scalar; Matern smoothness parameter. nu = 0.5 corresponds
to the Exponential correlation; nu = Inf corresponds to the Gaussian
correlation function.
Vector of length N; log of the signal standard deviation.
Vector of length N; log of the signal standard deviation.