dmnorm_sgv (and rmnorm_sgv) calculate the approximate SGV
likelihood for a fixed set of parameters (i.e., the U matrix). Finally,
the distributions must be registered within nimble.
rmnorm_sgv(n, mean, U, N, k)Not applicable.
Vector of measurements
Vector of mean valiues
Matrix of size N x 3; representation of a sparse N x N Cholesky of the precision matrix. The first two columns contain row and column indices, respectively, and the last column is the nonzero elements of the matrix.
Number of measurements in x
Number of neighbors for the SGV approximation.